---
title: "Book Review: the Righteous Mind"
date: 2017-11-30T23:14:18Z
tags: ["reviews","jonathan haidt","moral psychology","ethics","utilitarianism"]
topics: ["philosophy"]
image: img/righteous_mind.jpg
draft: false
---

Is it better to be truly just, or merely to seem so? This is the question put to Socrates by Glaucon in The Republic. Jonathan Haidt, in his book, “The Righteous Mind”, counts Glaucon among the cynics for putting this challenge to Socrates. But Haidt is missing a subtle and very powerful nuance in Plato’s story. Socrates had just finished embarrassing Thrasymachus for his weak defense of cynical egoism. Glaucon and Adeimantus were certainly entertained, but they were not satisfied with Socrates. They sought much stronger reasons for accepting the conclusion that true justice is preferable to appearance, because they did not want to merely seem to agree with Socrates. They *really wanted to believe* that genuine justice was better, and giving Socrates the strongest possible objection that could be mustered is the only way an honest man (if he is honest with himself) can do this.

Socrates’ initial response to Glaucon was not the description of the ideal state that the story has become famous for. Rather, it was a likening of the soul to the body. Repeated abuses and illnesses corrupt and degrade the health of the body over time, until at some point it is no longer possible to experience vigor and vitality. Likewise, says Socrates, repeated vices and injustices committed in pursuit of wealth or power or honor will eventually render the soul so degraded and corrupt that it will no longer be capable of achieving eudaemonia (aka ‘contentment’, ‘happiness’, or ‘flourishing’). This is the fate of the man who pursues a life of politics, without first tending to his soul.

Haidt seems almost proud of his “Glauconian cynicism” – a socio-biological view in which he believes he can show that, regardless of which is better, *seeming* just is what we humans *actually seek*. Haidt claims explicitly and confidently not to be offering an argument for what *ought to be*, only what *is*. But the enthusiasm with which he reports this supposed scientific fact suggests that he also thinks that what *is*, just is what *ought to be*. But this is precisely the challenge posed to Socrates by Glaucon: it certainly is true that many people (perhaps even most) are cynical and self-serving. So, why oughtn’t they be? Haidt’s response to this recurring implicit question seems to be to just keep reasserting the fact, in ever more sophisticated and complex ways.

Near the end of the book, in spite of already offering an explicit refusal to address the problem of normative ethics, Haidt tosses off a flippant endorsement of Utilitarianism as if this view has already settled the normative question, or simply to signal to the reader that the question just isn’t interesting enough to bother investigating. But this has profound implications for how seriously one can take some of the claims he makes in this book. The tension between what is and what ought to be plagues this book, and any reader eager for insight into the gap between descriptive and normative ethics will find it profoundly frustrating.

### The Basic Theory, and It’s Problems

Haidt’s basic theory of the “Righteous Mind” comes down to two hypotheses. First, that the human brain has evolved for both “tribal” and “hive” social structures. To put it in his terms, “we are 90% chimp, and 10% bee”, and a special “hive switch” in the brain is flipped, when conditions are ideal, that suppress our self-interested “groups” psychology, and make us more altruistically “hive-ish”. It’s not quite clear what sort of mechanism this “switch” is, what causes it to flip, and how it gets reset. But he offers a lot of anecdotes from his research that describe evidence suggesting its presence.

The second, and much more complex portion of the theory, is his six-dimensional model of moral psychology. His system is powerfully reminiscent of David Hume’s own four-pole system of moral emotions (Pride-vs-Humility / Love-vs-Hate). But there is one extremely significant difference. Hume’s theory was one meant to describe morality as a system of “passions” (special kinds of emotions). These passions derive from a natural propensity for pleasure, and a natural aversion to pain (he presages the Utilitarians in this respect). What’s more, moral judgments are not reasoned, but *felt*. Morality, for Hume, just is emotions expressed. Haidt’s theory, on the other hand, describes six dimensions of *values*, not emotions: Care, Fairness, Loyalty, Authority, Sanctity, and Liberty. Haidt says that all human beings have this six-dimensional system built-in as a consequence of thousands of years of socio-biological evolution. He argues that the “sensitivity level” at which each of these is not permanently fixed, but is set to “defaults” at birth, and adjusted over a lifespan by experience. How, precisely, this happens and by what mechanism, is a bit murky, but again, he offers loads of anecdotal examples (and data from his studies) to show how each of these dimensions is expressed by individuals.

A few questions and objections arose for me, about these two hypotheses, as I read through the book, that never seemed to get a satisfactory answer. First, on the six aspects: are they like adjuster knobs on a sound board? Or, are they merely barometer needles reporting varying pressure levels set by environmental impacts on a biological system? If the former, then surely there are “optimal” positions for each of these knobs (even if only circumstantially optimal)? In that case, then there is indeed an opening for a normative ethical theory, describing these optimums. However, if the latter is true, then it is hard to understand how there could be any such thing as an “ought” at all, much less a system prescribing them. Haidt is constantly nudging up to the edge of this Humean is-ought cliff, and retreating from it just when things start to get interesting.

Second, Haidt never quite explicitly acknowledges that he’s describing a *system of values*, rather than a moral psychology. One might object that a system of values could be said to be a variety of moral psychology, but I would reply that by the time we get to values, we’re already one layer above fundamental psychology. Why these six, and not others? Indeed, in the book, Haidt explicitly acknowledges that some early reviewers of the book objected to the lack of “equality” as a value on his list of “aspects”. If “liberty” counts as a foundational psychological value, then why not “equality”? It has just as long a history, after all. More importantly, to talk of values at all, you’re once again in flirting in the realm of the normative. I would have to look more closely at the research he used to back this section of the book, but how do we know he didn’t just happen to find the set of six values that he and his team were particularly focused on already? That is a normative selection process: “these values are more important than those”.

Third, returning to the “hive switch”, Haidt emphasizes the “dangers” of too much hive-ishness or too much groupishness. But he never quite explains how there could be any such thing as a “right amount” of either, in the absence of a *normative* theory. Without any idea of what an ideal amount of either would look like, why would the horror of the Hobbesian anarchy or Stalinist oppression even count as “bad”? Lower primates seem perfectly satisfied with brutal inter-tribal conflict, and ants are obliviously willing to destroy themselves en masse for the sake of colony and queen. What’s worse, is that there’s no clear explanation for how the “hive switch” and the six-dimensional moral psychology fit together. Do certain knob settings produce hives instead of tribes? Do others produce tribes instead of hives? What are the right tension levels between the two modes? If the knob settings do influence this, how do we know what those should be? None of this is discussed in the book, except in passionate warnings to beware of extremes. A laudable sentiment, but so what?

Lastly, while Frans de Waal is largely an asset to Haidt’s book, there is one key notion from de Waal that highlights the primary problem with Haidt’s “Glauconian moral matrix”; de Waal captured it in a rather pithy phrase: Veneer Theory. In his book, “Primates and Philosophers”, de Waal uses the phrase to criticize Huxley and Dawkins for uncritically accepting a view of human nature that is Hobbesian without providing an explanation for how a self-serving egoist gets to altruism all on his own. Haidt’s book suffers from a similar problem. Though he does a great job of bridging the gap between egoist and “group-altruist”, what he fails to do is explain how the “Glauconian cynic” becomes a genuinely caring being. Haidt has concocted his own variety of Veneer Theory by redefining it as a complex inter-subjective social delusion that we all agree to participate in. He takes this as an *answer* to the problem of a “veneer” layer. But it only makes his own set of theories seem like a Rube Goldberg machine. Haidt makes a strong case for the biological and psychological *reality* of moral experience as a genuine phenomenon. But this works directly against the idea that we merely wish to *appear* to care, or to be virtuous. Why layer a “moral matrix” on top of a perfectly reasonable explanation of genuine moral emotions? More to the point, why would evolution tolerate such an expensive and convoluted cognitive load, such as layers of delusion, on top of the already demanding task of navigating the social world in real time? Even more curiously, why would we count the primitive primate morality of chimps and bonobos as “actual” or “genuine”, while regarding our own as a mere matrix-like delusion?

### Final Thoughts

Anyone who has read the entirety of The Republic has to come to terms with a powerful dissonance in Plato’s tale. Either Socrates truly misunderstood human nature (perhaps he confused it with his own psychological projections), or he didn’t actually believe what he was saying. Some philosophers argue for the latter theory: that the ideal state was ideal *intentionally*. Socrates was never going to convince the Athenians to drive all the old folks out of the city in order to start afresh, or convince the educated classes to surrender their private property holdings to the commons, or convince them to put their women and children into a breeding commune to be tended by specially bred and trained guardians. He must have known that. What was really going on here? Remember that the tale was written by Plato, long after Socrates’ execution. Plato was engaging in his own bit of *cynical rhetoric*, grounded in bitterness. He wanted to demonstrate the utter impossibility of the larger task: convincing men to love virtue for its own sake; to *be* just, rather than simply to *appear* just. He had given up on the possibility, and the Republic was his way of showing this. It is hard to blame him, on one level. He’d watched these people destroy his master and teacher; a man for whom Plato had given up a promising life as a poet, in order to follow him in philosophy. Haidt, on the other hand, embraces his cynicism with zeal, because he believes the data tells him he must, and he refuses to even entertain the possibility that we might just be better than that. In effect, he takes Plato’s implicit condemnation of man and turns it into a simple matter-of-fact. But recasting the condemnation as mere description doesn’t change the moral reality; it just hides it behind a veil of cynicism.
